@@ -24,11 +24,3 @@ class SwatchTime:
 	def __str__(self):
 		return f"{self.get()} .beats"
 
-
-
-if __name__ == "__main__":
-	print(SwatchTime())
-
-
-
-
